<?
if (!defined("_GNUBOARD_")) exit; // 개별 페이지 접근 불가 


?>

	<?if($select_right_c){?><td width="<?=$right_c?>"></td><?}?>


    <?if($select_right){?>
      <td width="<?=$right_width?>" align="center"  valign="top" >
	       <table width="100%" height="100%"  border="0" cellspacing="0" cellpadding="0" >
		   <tr><td><?=banner_sero("우측배너1")?></td></tr>
		   <tr><td><?=latest_all("", "실시간 최신글", "5", "22", "bn_id", "" ,"60","0");// (스킨,타이틀제목, 출력수량, 제목길이, 정렬순서-wr_hit bn_id , 확장옵션, 검색시작일, 검색종료일)?></td></tr>
		   <tr><td height="5"></td></tr>
		   <tr><td><?=latest_photo("", "최신포토갤러리", "4", "12", "bf_datetime", "72*48*2" ,"60", "0");//(스킨, 타이틀제목, 출력수량, 제목길이, 정렬순서, "가로사이즈*세로사이즈*출력수량, 검색시작일, 검색종료일")?></td></tr>
		   <tr><td height="5"></td></tr>
		   <tr><td><?=latest_all("", "지난주 시선집중", "8", "22", "wr_hit", "" ,"14","7");// (스킨,타이틀제목, 출력수량, 제목길이, 정렬순서-wr_hit bn_id , 확장옵션, 검색시작일, 검색종료일)?></td></tr>
		   <tr><td height="5"></td></tr>
		   <tr><td><?=latest_photo("", "주간포토", "2", "12", "bf_datetime", "72*48*2" ,"120", "3");//(스킨, 타이틀제목, 출력수량, 제목길이, 정렬순서, "가로사이즈*세로사이즈*출력수량, 검색시작일, 검색종료일")?></td></tr>
		   <tr><td height="5"></td></tr>
		   <tr><td><? echo  if_conf_pro("8", "5", $show, "", $options="$gr_id"); //게시판 환경설정에서 메인 노출 8 선택시?></td></tr>
		   </table>
      </td>
    <?}?>
</tr>
<tr>
    <td colspan="<?=$a_colspan?>" height="5"></td>
</tr>
<tr>
    <td colspan="<?=$a_colspan?>"  valign="top">
<?
 if(!$bo_table){
 include_once("$g4[path]/include/site_map.php"); // 사이트맵
	}

?>
	</td>
</tr>
<tr>
    <td colspan="<?=$a_colspan?>" height="5"></td>
</tr>
<tr>
    <td colspan="<?=$a_colspan?>"  valign="top">
    <?
       echo menu_gr("tail", $gr_id,$bo_table, 9, 17, "100%" , "");//상단메뉴
	?>	
	</td>
</tr>

</table>







<?

//새창관리
include_once("$g4[path]/shop/popup.php"); 

include_once("$g4[path]/tail.sub.php");
?>